@@ -4,7 +4,7 @@
 from .quantity import Dimension, Quantity
 from .quantity import DimensionError, SI_UNIT_SYMBOL
 from .quantity import quantify, make_quantity, dimensionify
-from .utils import check_dimension, set_favunit, dimension_and_favunit, drop_dimension, add_back_unit_param, decorate_with_various_unit, array_to_Q_array, asqarray
+from .utils import check_dimension, set_favunit, dimension_and_favunit, drop_dimension, add_back_unit_param, decorate_with_various_unit, asqarray
 
 from .calculus import *
 
