@@ -16,48 +16,73 @@ import sympy as sp
 
 from .dimension import Dimension, DimensionError, SI_UNIT_SYMBOL
 from .quantity import quantify, Quantity
-from .utils import array_to_Q_array, decorate_with_various_unit, asqarray
-
-
-
-def vectorize(func):
-    """Allow vectorize a function of Quantity.
-    
-    This function aims to extend numpy.vectorize to Quantity-function.
-    
-    """
-    func_vec = np.vectorize(func)
-    def func_Q_vec(*args, **kwargs):
-        res_brute = func_vec(*args, **kwargs)
-        res = asqarray(res_brute)
-        return res
-    return func_Q_vec
+from .utils import decorate_with_various_unit, asqarray
 
 
 def xvectorize(func):
+    """
+    1-D vectorize func.
+    
+    func must have signature 'func(arg)', and vectorization is made along arg.
+    Returned value will be a Quantity object, even if returned values are 
+    dimensionless (because of the use of asqarray).
+    
+    Just like np.vectorize, this decorator is a utility to wrap a for loop - 
+    it does not improve performance in any way.
+    
+    Parameter
+    ---------
+    func : callable
+        A function of one parameter.
+        
+    Returns
+    -------
+    callable
+        Decorated function.
+    """
     def vec_func(x):
         res = []
         for i in x:
             res.append(func(i))
-        res = np.array(res, dtype=object)
         res = asqarray(res)
         return res
     return vec_func
 
 
 def ndvectorize(func):
+    """
+    1-D vectorize func and accept input as ndarray.
+    
+    func must have signature 'func(arg)', and vectorization is made along arg.
+    Returned value will be a Quantity object, even if returned values are 
+    dimensionless (because of the use of asqarray).
+    
+    Basically, func is applied to each value in arg input (as a flat list), 
+    and output is reshaped to input shape.
+    
+    Just like np.vectorize, this decorator is a utility to wrap a for loop - 
+    it does not improve performance in any way.
+    
+    Parameter
+    ---------
+    func : callable
+        A function of one parameter.
+        
+    Returns
+    -------
+    callable
+        Decorated function.
+    """
     def vec_func(x):
         res = []
         for i in x.flat:
             res.append(func(i))
-        res = np.array(res, dtype=object)
         res = asqarray(res)
         res.value = res.value.reshape(x.shape)
         return res
     return vec_func
 
 
-
 def trapz2(Zs, ech_x, ech_y):
     """
     2D integral based on trapz.
@@ -83,6 +108,7 @@ def trapz2(Zs, ech_x, ech_y):
     int_xy = np.trapz(int_x, axis=-1, x=ech_y)
     return int_xy
 
+
 def main():
     pass
 
