@@ -728,11 +728,11 @@ class Quantity(object):
             raise AttributeError("Neither Quantity object nor its value ({}) "
                                  "has attribute '{}'".format(self.value, item))
     
-    def to_numpy(self):
-        """
-        Needed for plt.hist(np.arange(10)*m).
-        """
-        return np.asarray(self.value)
+    #def to_numpy(self):
+    #    """
+    #    Needed for plt.hist(np.arange(10)*m).
+    #    """
+    #    return np.asarray(self.value)
     
     def reshape(self, *args, **kwargs):
         return type(self)(self.value.reshape(*args, **kwargs), self.dimension)
@@ -793,18 +793,18 @@ class Quantity(object):
                 
         # hypot doesn't have a reduce
         if ufunc_name in same_dim_out_2 and ufunc_name != "hypot":
-            res = ufunc.reduce(left.value)    
+            res = ufunc.reduce(left.value, **kwargs)
             return type(self)(res, left.dimension)
         # only multiply seems to be possible
         elif ufunc_name in skip_2:
-            res = ufunc.reduce(left.value)    
+            res = ufunc.reduce(left.value, **kwargs)    
             if ufunc_name == "multiply" or ufunc_name == "matmul":
                 return type(self)(res, left.dimension ** len(left.value))
             else:
                 raise NotImplementedError(f"array ufunc {ufunc} with method {method} not implemented")
         # return booleans : 
         elif ufunc_name in same_dim_in_2_nodim_out:
-            res =  ufunc.reduce(left.value)    
+            res =  ufunc.reduce(left.value, **kwargs)    
             return res
         # ValueError: reduce only supported for binary functions
         elif ufunc_name in unary_ufuncs:
@@ -1319,11 +1319,6 @@ def np_rot90(m, k=1, axes=(0,1)):
                     symbol=m.symbol)
 
 
-@implements(np.alen)
-def np_alen(a):
-    return np.alen(a.value)
-
-
 @implements(np.lib.stride_tricks.sliding_window_view)
 def np_lib_stride_tricks_sliding_window_view(x, *args, **kwargs):
     raw = np.lib.stride_tricks.sliding_window_view(x.value, *args, **kwargs)
