@@ -16,12 +16,12 @@ from physipy.quantity import Dimension, Quantity, DimensionError
 #from quantity import DISPLAY_DIGITS, EXP_THRESHOLD
 from physipy.integrate import quad, dblquad, tplquad, solve_ivp
 from physipy.optimize import root, brentq
-from physipy.quantity import vectorize #turn_scalar_to_str
+#from physipy.quantity import vectorize #turn_scalar_to_str
 from physipy.quantity.calculus import xvectorize, ndvectorize
 from physipy.quantity import SI_units, units#, custom_units
 from physipy.quantity import m, s, kg, A, cd, K, mol
 from physipy.quantity import quantify, make_quantity, dimensionify
-from physipy.quantity import check_dimension, set_favunit, dimension_and_favunit, drop_dimension, add_back_unit_param, decorate_with_various_unit, array_to_Q_array
+from physipy.quantity import check_dimension, set_favunit, dimension_and_favunit, drop_dimension, add_back_unit_param, decorate_with_various_unit
 from physipy.quantity.utils import asqarray
 from physipy import imperial_units, setup_matplotlib
 from physipy.quantity.utils import qarange
@@ -996,10 +996,7 @@ class TestQuantity(unittest.TestCase):
         
         arr = np.array([1,2,3])
         arr_m = Quantity(arr, Dimension("L"))
-        
-        # np.alen
-        self.assertEqual(np.alen(3*m), np.alen(3))
-        self.assertEqual(np.alen(np.arange(3)*m), np.alen(np.arange(3)))
+
         
         # np.all
         
@@ -1796,6 +1793,7 @@ class TestQuantity(unittest.TestCase):
         self.assertTrue(np.all(exp == res))     
         
     def test_xvectorize(self):
+        # func returns dimensionfull value
         arr_m = np.arange(5)*m
         
         def thresh(x):
@@ -1809,6 +1807,21 @@ class TestQuantity(unittest.TestCase):
         exp = np.array([3, 3, 3, 3, 4])*m
         self.assertTrue(np.all(res == exp))
         
+        
+        # func returns dimensionless value
+        arr_m = np.arange(5)*m
+        
+        def thresh(x):
+            if x >3*m:
+                return x/m
+            else:
+                return 3
+        vec_thresh = xvectorize(thresh)
+        
+        res = vec_thresh(arr_m)
+        exp = np.array([3, 3, 3, 3, 4])
+        self.assertTrue(np.all(res == exp))
+        
     #def test_vectorize(self):
     #    
     #    # 1D array
@@ -1841,6 +1854,7 @@ class TestQuantity(unittest.TestCase):
         
         
     def test_ndvectorize(self):
+        # func returns dimensionfull value
         arr_m = np.arange(6).reshape(3,2)*m
         
         def thresh(x):
@@ -1854,6 +1868,21 @@ class TestQuantity(unittest.TestCase):
         exp = np.array([[3, 3],[3, 3], [4, 5]])*m
         self.assertTrue(np.all(res == exp))
 
+        
+        # func returns dimensionless value
+        arr_m = np.arange(6).reshape(3,2)*m
+        
+        def thresh(x):
+            if x >3*m:
+                return x/m
+            else:
+                return 3
+        vec_thresh = ndvectorize(thresh)
+        
+        res = vec_thresh(arr_m)
+        exp = np.array([[3, 3],[3, 3], [4, 5]])
+        self.assertTrue(np.all(res == exp))
+
 
     def test_np_fft_fftshift(self):
         exp = np.fft.fftshift(np.arange(10))*s
@@ -1979,29 +2008,125 @@ class TestQuantity(unittest.TestCase):
         exp = np.multiply.reduce(np.arange(10))*m**10
         self.assertEqual(res, exp)        
     def test_np_greater_reduce(self):
-        res = np.greater.reduce(np.arange(10)*m)
-        exp = np.greater.reduce(np.arange(10))
+        # see https://github.com/numpy/numpy/issues/20929
+        arr = np.arange(10)    
+            
+        # with dtype bool
+        exp = np.greater.reduce(arr, dtype=bool)
+        res = np.greater.reduce(arr*m, dtype=bool)
         self.assertEqual(res, exp)
+
+        # as object
+        exp = np.greater.reduce(arr.astype(object))
+        res = np.greater.reduce(arr.astype(object)*m)
+        self.assertEqual(res, exp)
+
+        # error on raw input
+        with self.assertRaises(TypeError):
+            np.greater.reduce(arr)
+        with self.assertRaises(TypeError):
+            np.greater.reduce(arr*m)    
+            
     def test_np_greater_equal_reduce(self):
-        res = np.greater_equal.reduce(np.arange(10)*m)
-        exp = np.greater_equal.reduce(np.arange(10))
+        # see https://github.com/numpy/numpy/issues/20929
+        arr = np.arange(10)    
+            
+        # with dtype bool
+        exp = np.greater_equal.reduce(arr, dtype=bool)
+        res = np.greater_equal.reduce(arr*m, dtype=bool)
         self.assertEqual(res, exp)
+
+        # as object
+        exp = np.greater_equal.reduce(arr.astype(object))
+        res = np.greater_equal.reduce(arr.astype(object)*m)
+        self.assertEqual(res, exp)
+
+        # error on raw input
+        with self.assertRaises(TypeError):
+            np.greater_equal.reduce(arr)
+        with self.assertRaises(TypeError):
+            np.greater_equal.reduce(arr*m)    
+            
     def test_np_less_reduce(self):
-        res = np.less.reduce(np.arange(10)*m)
-        exp = np.less.reduce(np.arange(10))
+        # see https://github.com/numpy/numpy/issues/20929
+        arr = np.arange(10)    
+            
+        # with dtype bool
+        exp = np.less.reduce(arr, dtype=bool)
+        res = np.less.reduce(arr*m, dtype=bool)
         self.assertEqual(res, exp)
+
+        # as object
+        exp = np.less.reduce(arr.astype(object))
+        res = np.less.reduce(arr.astype(object)*m)
+        self.assertEqual(res, exp)
+
+        # error on raw input
+        with self.assertRaises(TypeError):
+            np.less.reduce(arr)
+        with self.assertRaises(TypeError):
+            np.less.reduce(arr*m)    
+        
     def test_np_less_equal_reduce(self):
-        res = np.less_equal.reduce(np.arange(10)*m)
-        exp = np.less_equal.reduce(np.arange(10))
+        # see https://github.com/numpy/numpy/issues/20929
+        arr = np.arange(10)    
+            
+        # with dtype bool
+        exp = np.less_equal.reduce(arr, dtype=bool)
+        res = np.less_equal.reduce(arr*m, dtype=bool)
         self.assertEqual(res, exp)
+
+        # as object
+        exp = np.less_equal.reduce(arr.astype(object))
+        res = np.less_equal.reduce(arr.astype(object)*m)
+        self.assertEqual(res, exp)
+
+        # error on raw input
+        with self.assertRaises(TypeError):
+            np.less_equal.reduce(arr)
+        with self.assertRaises(TypeError):
+            np.less_equal.reduce(arr*m)    
+            
     def test_np_not_equal_reduce(self):
-        res = np.not_equal.reduce(np.arange(10)*m)
-        exp = np.not_equal.reduce(np.arange(10))
+        # see https://github.com/numpy/numpy/issues/20929
+        arr = np.arange(10)    
+            
+        # with dtype bool
+        exp = np.not_equal.reduce(arr, dtype=bool)
+        res = np.not_equal.reduce(arr*m, dtype=bool)
         self.assertEqual(res, exp)
+
+        # as object
+        exp = np.not_equal.reduce(arr.astype(object))
+        res = np.not_equal.reduce(arr.astype(object)*m)
+        self.assertEqual(res, exp)
+
+        # error on raw input
+        with self.assertRaises(TypeError):
+            np.not_equal.reduce(arr)
+        with self.assertRaises(TypeError):
+            np.not_equal.reduce(arr*m)    
+        
     def test_np_equal_reduce(self):
-        res = np.equal.reduce(np.arange(10)*m)
-        exp = np.equal.reduce(np.arange(10))
+        # see https://github.com/numpy/numpy/issues/20929
+        arr = np.arange(10)    
+            
+        # with dtype bool
+        exp = np.equal.reduce(arr, dtype=bool)
+        res = np.equal.reduce(arr*m, dtype=bool)
         self.assertEqual(res, exp)
+
+        # as object
+        exp = np.equal.reduce(arr.astype(object))
+        res = np.equal.reduce(arr.astype(object)*m)
+        self.assertEqual(res, exp)
+
+        # error on raw input
+        with self.assertRaises(TypeError):
+            np.equal.reduce(arr)
+        with self.assertRaises(TypeError):
+            np.equal.reduce(arr*m)    
+        
     def test_np_floor_dividel_reduce(self):
         res = np.floor_divide.reduce(np.arange(10)*m)
         exp = np.floor_divide.reduce(np.arange(10))
